@@ -31,7 +31,7 @@ from copy import deepcopy
 # third-party
 import xmltodict
 
-__version__ = "1.0.3"
+__version__ = "1.1.0"
 
 log = logging.getLogger(__name__)
 
@@ -85,8 +85,8 @@ def _get_codeclimate_severity(valgrind_severity: str) -> str:
 def convert_file(
     fname_in: str,
     fname_out: str,
+    base_dirs: typing.List[str],
     file_concat: typing.Optional[str] = None,
-    base_dirs: typing.Optional[list] = None,
     relative_dir: typing.Optional[str] = None,
 ) -> int:
     """Convert valgrind XML file to GitLab-compatible "Code Quality" JSON report
@@ -96,10 +96,10 @@ def convert_file(
           Input file path (valgrind XML). Like 'valgrind.xml'.
         fname_out (str):
           Output file path (code quality JSON). Like 'valgrind.json'.
-        file_concat (str):
-          File path (JSON) contains code quality informations from previous analyze.
         base_dirs (list):
           Base directories where source files with relative paths can be found.
+        file_concat (str):
+          File path (JSON) contains code quality informations from previous analyze.
         relative_dir (str):
           Absolute path to change absolute path to relative from this path.
 
@@ -199,7 +199,7 @@ def _get_line_from_file(filename: str, line_number: int) -> str:
 
 def _convert(
     xml_input,
-    base_dirs: typing.Optional[typing.List[str]] = None,
+    base_dirs: typing.List[str],
     relative_dir: typing.Optional[str] = None,
     dict_concat: typing.Optional[typing.Dict[str, str]] = None,
 ) -> typing.Tuple[str, int]:
@@ -252,7 +252,7 @@ def _convert(
 
     for error in errors:
 
-        log.debug("Processing -- %s", str(error))
+        log.debug("Processing error -- %s", str(error["unique"]))
 
         # Some information messages are not related to the code.
         # Let's let the user know, then skip.
@@ -279,21 +279,15 @@ def _convert(
         line = -1
         for index in range(len(stacks[0]["frame"])):
             frame = stacks[0]["frame"][index]
-            first_frames = stacks[0]["frame"][index]
+            log.debug("- Analyse frames -- %s", str(frame["ip"]))
             if "dir" in frame and "file" in frame:
-                path = os.path.join(frame["dir"], frame["file"])
-                line = int(first_frames["line"])
+                line = int(frame["line"])
 
-                # File path not found
-                if not os.path.isfile(path):
-                    path = ""
-                    # Check in base dirs
-                    if isinstance(base_dirs, list):
-                        for d in base_dirs:
-                            tmp_path = os.path.join(d, frame["file"])
-                            if os.path.isfile(tmp_path):
-                                path = tmp_path
-                                break
+                # Check in base dirs
+                for d in base_dirs:
+                    if d in frame["dir"]:
+                        path = os.path.join(frame["dir"], frame["file"])
+                        break
 
                 if path == "":
                     continue
@@ -308,6 +302,9 @@ def _convert(
                 tmp_dict["location"]["path"] = path
             tmp_dict["location"]["lines"]["begin"] = line
 
+            log.debug("-- File -- %s", path)
+            log.debug("-- Line -- %s", line)
+
             # GitLab requires the fingerprint field. Code Climate describes this as
             # being used to uniquely identify the issue, so users could "exclude it
             # from future analysis."
